import {
  select,
  timeParse,
  csvParse,
  min,
  max,
  extent,
} from 'd3';
import { lineChart } from './lineChart';

export const viz = (container, options) => {
  const [state, setState] = options;
  const { data } = state;

  const width = innerWidth;
  const height = innerHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  if (data && data !== 'LOADING') {
    const xValue = (d) => d.date;
    const yValue = (d) => d.average;

    svg.call(lineChart, {
      data,
      width,
      height,
      xValue,
      yValue,
      xAxisLabel: 'Year',
      yAxisLabel: 'CO2 Concentration',
      margin: {
        top: 20,
        left: 60,
        bottom: 60,
        right: 20,
      },
    });
  }

  if (!data) {
    setState((prev) => ({ ...prev, data: 'LOADING' }));

    fetch('data.csv')
      .then((res) => res.text())
      .then((csvString) => {
        const data = csvParse(csvString);
        const parseDate = timeParse('%Y-%m');

        data.forEach((d) => {
          (d.average = +d.average),
            (d.deseasonalized = +d.deseasonalized),
            (d.date = parseDate(`${d.year}-${d.month}`));
        });

        setState((prev) => ({ ...prev, data: data }));
      });
  }
};
